@@ -4,31 +4,6 @@
 #include <clutter/clutter.h>
 #include <cogl/cogl.h>
 
-#ifndef GL_UNPACK_ALIGNMENT
-#define GL_UNPACK_ALIGNMENT 0x0CF5
-#endif
-#ifndef GL_TEXTURE_BINDING_2D
-#define GL_TEXTURE_BINDING_2D 0x8069
-#endif
-#ifndef GL_TEXTURE_2D
-#define GL_TEXTURE_2D 0x0DE1
-#endif
-#ifndef GL_RGB
-#define GL_RGB 0x1907
-#endif
-#ifndef GL_UNSIGNED_BYTE
-#define GL_UNSIGNED_BYTE 0x1401
-#endif
-#ifndef GL_TEXTURE_MAG_FILTER
-#define GL_TEXTURE_MAG_FILTER 0x2800
-#endif
-#ifndef GL_LINEAR
-#define GL_LINEAR 0x1208
-#endif
-#ifndef GL_TEXTURE_MIN_FILTER
-#define GL_TEXTURE_MIN_FILTER 0x2801
-#endif
-
 /* Coglbox declaration
  *--------------------------------------------------*/
 
@@ -93,27 +68,8 @@ G_DEFINE_TYPE (TestCoglbox, test_coglbox, CLUTTER_TYPE_ACTOR);
 
 struct _TestCoglboxPrivate
 {
-  guint      gl_handle;
+  GLuint     gl_handle;
   CoglHandle cogl_handle;
-
-  void
-  (* glGetIntegerv) (guint pname, int *params);
-  void
-  (* glPixelStorei) (guint pname, int param);
-  void
-  (* glTexParameteri) (guint target, guint pname, int param);
-  void
-  (* glTexImage2D) (guint target, int level,
-                    int internalFormat,
-                    int width, int height,
-                    int border, guint format, guint type,
-                    const void *pixels);
-  void
-  (* glGenTextures) (int n, guint *textures);
-  void
-  (* glDeleteTextures) (int n, const guint *textures);
-  void
-  (* glBindTexture) (guint target, guint texture);
 };
 
 /* Coglbox implementation
@@ -155,7 +111,7 @@ test_coglbox_dispose (GObject *object)
   priv = TEST_COGLBOX_GET_PRIVATE (object);
   
   cogl_handle_unref (priv->cogl_handle);
-  priv->glDeleteTextures (1, &priv->gl_handle);
+  glDeleteTextures (1, &priv->gl_handle);
   
   G_OBJECT_CLASS (test_coglbox_parent_class)->dispose (object);
 }
@@ -165,8 +121,8 @@ test_coglbox_init (TestCoglbox *self)
 {
   TestCoglboxPrivate *priv;
   guchar              data[12];
-  int prev_unpack_alignment;
-  int prev_2d_texture_binding;
+  GLint prev_unpack_alignment;
+  GLint prev_2d_texture_binding;
   
   self->priv = priv = TEST_COGLBOX_GET_PRIVATE(self);
   
@@ -177,35 +133,27 @@ test_coglbox_init (TestCoglbox *self)
   data[6] =   0; data[7]  =   0; data[8]  = 255;
   data[9] =   0; data[10] =   0; data[11] =   0;
 
-  priv->glGetIntegerv = (void *) cogl_get_proc_address ("glGetIntegerv");
-  priv->glPixelStorei = (void *) cogl_get_proc_address ("glPixelStorei");
-  priv->glTexParameteri = (void *) cogl_get_proc_address ("glTexParameteri");
-  priv->glTexImage2D = (void *) cogl_get_proc_address ("glTexImage2D");
-  priv->glGenTextures = (void *) cogl_get_proc_address ("glGenTextures");
-  priv->glDeleteTextures = (void *) cogl_get_proc_address ("glDeleteTextures");
-  priv->glBindTexture = (void *) cogl_get_proc_address ("glBindTexture");
-
   /* We are about to use OpenGL directly to create a TEXTURE_2D
    * texture so we need to save the state that we modify so we can
    * restore it afterwards and be sure not to interfere with any state
    * caching that Cogl may do internally.
    */
-  priv->glGetIntegerv (GL_UNPACK_ALIGNMENT, &prev_unpack_alignment);
-  priv->glGetIntegerv (GL_TEXTURE_BINDING_2D, &prev_2d_texture_binding);
+  glGetIntegerv (GL_UNPACK_ALIGNMENT, &prev_unpack_alignment);
+  glGetIntegerv (GL_TEXTURE_BINDING_2D, &prev_2d_texture_binding);
 
-  priv->glGenTextures (1, &priv->gl_handle);
-  priv->glBindTexture (GL_TEXTURE_2D, priv->gl_handle);
+  glGenTextures (1, &priv->gl_handle);
+  glBindTexture (GL_TEXTURE_2D, priv->gl_handle);
   
-  priv->glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
-  priv->glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB,
+  glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
+  glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB,
 		2, 2, 0, GL_RGB, GL_UNSIGNED_BYTE, data);
 
   /* Now restore the original GL state as Cogl had left it */
-  priv->glPixelStorei (GL_UNPACK_ALIGNMENT, prev_unpack_alignment);
-  priv->glBindTexture (GL_TEXTURE_2D, prev_2d_texture_binding);
+  glPixelStorei (GL_UNPACK_ALIGNMENT, prev_unpack_alignment);
+  glBindTexture (GL_TEXTURE_2D, prev_2d_texture_binding);
   
-  priv->glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  priv->glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
   
   /* Create texture from foreign */
   
@@ -251,11 +199,10 @@ test_cogl_tex_foreign_main (int argc, char *argv[])
     return 1;
   
   /* Stage */
-  stage = clutter_stage_new ();
+  stage = clutter_stage_get_default ();
   clutter_actor_set_size (stage, 400, 400);
-  clutter_stage_set_title (CLUTTER_STAGE (stage), "Cogl Foreign Textures");
-  g_signal_connect (stage, "destroy", G_CALLBACK (clutter_main_quit), NULL);
-
+  clutter_stage_set_title (CLUTTER_STAGE (stage), "Cogl Test");
+  
   /* Cogl Box */
   coglbox = test_coglbox_new ();
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), coglbox);
@@ -266,9 +213,3 @@ test_cogl_tex_foreign_main (int argc, char *argv[])
   
   return 0;
 }
-
-G_MODULE_EXPORT const char *
-test_cogl_tex_foreign_describe (void)
-{
-  return "Foreign textures support in Cogl.";
-}
